@@ -8,6 +8,7 @@ sub new {
 
     my (@libs, @includes);
 
+    print "Probing for mpfr and gmp libraries and header files...\n";
     for my $env (grep { exists $ENV{$_} } qw(GMP_HOME MPFR_HOME)) {
         push @includes, File::Spec->catdir($ENV{$env}, "include");
         push @libs,     File::Spec->catdir($ENV{$env}, "lib");
@@ -20,6 +21,13 @@ sub new {
         $ENV{MPFR_LIBS}     ||= join " ", map { "-L$_" } @libs;
     }
 
+    if (! @includes) {
+        print "No include directories detected\n";
+    }
+    if (! @libs) {
+        print "No link directories detected\n";
+    }
+
     print "Detected the following MPFR settings:\n";
 
     foreach my $env (qw(MPFR_HOME MPFR_INCLUDES MPFR_LIBS)) {
